@@ -1,7 +1,9 @@
 #
-# Copyright (c) 2011-2015 T.Linden <tlinden |AT| cpan.org>.
-# All Rights Reserved. Std. disclaimer applies.
-# Artistic License, same as perl itself. Have fun.
+# Copyright (c) 2011-2015 T.v.Dein <tlinden |AT| cpan.org>.
+#
+# Licensed under the terms of the Artistic License 2.0
+# see: http://www.perlfoundation.org/artistic_license_2_0
+#
 #
 package Crypt::PWSafe3::HeaderField;
 
@@ -11,7 +13,7 @@ use Exporter ();
 use vars qw(@ISA @EXPORT);
 use utf8;
 
-$Crypt::PWSafe3::HeaderField::VERSION = '1.03';
+$Crypt::PWSafe3::HeaderField::VERSION = '1.04';
 
 %Crypt::PWSafe3::HeaderField::map2name = (
 	    0x00 => "version",
@@ -196,18 +198,18 @@ L<Crypt::PWSafe3>
 
 =head1 AUTHOR
 
-T. Linden <tlinden@cpan.org>
+T.v.Dein <tlinden@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 by T.Linden <tlinden@cpan.org>.
+Copyright (c) 2011-2015 by T.v.Dein <tlinden@cpan.org>.
 All rights reserved.
 
 =head1 LICENSE
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
-
+and/or modify it under the same terms of the Artistic
+License 2.0, see: L<http://www.perlfoundation.org/artistic_license_2_0>
 
 =cut
 
