@@ -1,13 +1,14 @@
 #
-# Copyright (c) 2011-2015 T.Linden <tlinden |AT| cpan.org>.
-# All Rights Reserved. Std. disclaimer applies.
-# Artistic License, same as perl itself. Have fun.
+# Copyright (c) 2011-2015 T.v.Dein <tlinden |AT| cpan.org>.
+#
+# Licensed under the terms of the Artistic License 2.0
+# see: http://www.perlfoundation.org/artistic_license_2_0
 #
 # helper class to provide SHA-256 to HMAC class
 
 package Crypt::PWSafe3::SHA256;
 
-$Crypt::PWSafe3::SHA256::VERSION = '1.01';
+$Crypt::PWSafe3::SHA256::VERSION = '1.02';
 
 use Digest::SHA;
 
@@ -38,7 +39,7 @@ instead.
 
 =head1 AUTHOR
 
-T. Linden <tlinden@cpan.org>
+T.v.Dein <tlinden@cpan.org>
 
 =head1 SEE ALSO
 
@@ -48,13 +49,13 @@ L<Digest::HMAC>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011-2015 by T.Linden <tlinden@cpan.org>.
-All rights reserved.
+Copyright (c) 2011-2015 by T.v.Dein <tlinden@cpan.org>.
 
 =head1 LICENSE
 
 This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
+and/or modify it under the same terms of the Artistic
+License 2.0, see: L<http://www.perlfoundation.org/artistic_license_2_0>
 
 =cut
 
